@@ -1,9 +1,9 @@
-"""Play a game of chess in Python module mode, i.e. `python -m chess`."""
+"""Play a game of chess in the terminal."""
 
 from importlib.util import find_spec
 from sys import argv
 
-from . import asciiconsole
+from . import __version__, asciiconsole
 
 RICH_AVAILABLE = find_spec("rich") is not None
 
@@ -19,7 +19,9 @@ if TEXTUAL_AVAILABLE:
 def main() -> None:
     """Start chess."""
     args = " ".join(argv)
-    if (
+    if "-v" in args:
+        print(f"consolechess {__version__}")
+    elif (
         "ascii" in args
         or "-a" in args
         or (not RICH_AVAILABLE and not TEXTUAL_AVAILABLE)
