@@ -1,6 +1,6 @@
 """Types for ChessBoard."""
 
-from collections.abc import Callable, Iterator
+from collections.abc import Callable
 from dataclasses import dataclass
 from typing import Literal
 
@@ -17,20 +17,37 @@ StatusDescription = Literal[
     "the_50_move_rule",
     "the_75_move_rule",
     "insufficient_material",
+    "imported",
+    "explosion",
+    "three_check",
 ]
-SquareGenerator = Callable[[str], Iterator[str]]
-StepFunction = Callable[[str, int], str]
+SquareGenerator = Callable[[str], list[str]]
+StepFunction = Callable[[str, int], str | None]
 
 
-@dataclass(frozen=True, slots=True)
+@dataclass(slots=True)
 class Piece:
     """A piece on a chess board."""
 
     piece_type: PieceType
     color: Color
+    promoted: bool = False
+    has_moved: bool = False
+
+    def __eq__(self: "Piece", other: object) -> bool:
+        """Check if two pieces are of the same type and color."""
+        return (
+            (self.piece_type == other.piece_type and self.color == other.color)
+            if isinstance(other, Piece)
+            else False
+        )
+
+    def __hash__(self: "Piece") -> int:
+        """Hash piece (ignores metadata)."""
+        return hash((self.piece_type, self.color))
 
 
-@dataclass(slots=True)
+@dataclass(frozen=True, slots=True)
 class GameStatus:
     """Status of the game."""
 
