@@ -11,7 +11,3 @@ class InvalidNotationError(Exception):
 
 class OtherPlayersTurnError(Exception):
     """Raised if player moves a white piece on black's turn or vice-versa."""
-
-
-class OffGridError(Exception):
-    """Raised when a square does not exist."""
